@@ -2,7 +2,8 @@ import nwborglab
 import os
 from os.path import expanduser
 from datetime import datetime as dt
-from SAPOFTO import SAPOFTO, recursiveFolderWrite, recursiveFolderRead
+from SAPOFTO import SAPOFTO
+import SAPOFTO as sapf
 from pynwb import NWBHDF5IO
 
 
@@ -50,11 +51,14 @@ def init(args):
        		   		   v0.0.1""")
     
     if len(args) > 0:
-        print('attempting nwborglab initialization from file')
-        if not os.isfile(args[0]) :
+        print('INIT ERROR: attempting nwborglab initialization from file')
+        if not os.path.isfile(args[0]):
             print(args[0] + ' no such file :(')
         if not args[0].endswith('.nwb'):
-            io = NWBHDF5IO(args[0], 'r')
+            print('INIT ERROR: specified file is not an nwb file')
+            return
+        io = NWBHDF5IO(args[0], 'r')
+        nwbfile_in = io.read()
 
         print(nwbfile_in.get_scratch('nwborglab_sensors'))
         sensors_sapofto = SAPOFTO('sensors',nwbfile_in.get_scratch('nwborglab_sensors'), case_sensitive=True)
@@ -62,7 +66,7 @@ def init(args):
         session_skeleton_sapofto = nwbfile_in.get_scratch('nwborglab_session_skeleton')
         session_skeleton_sapofto = nwbfile_in.get_scratch('nwborglab_session_source_code')
         
-        recursiveFolderWrite(os.getcwd())
+        sapf.recursiveFolderWrite(os.getcwd())
         return
     
     tab = '    '
