@@ -149,6 +149,14 @@ def generateSessionCode(args):
                         
     session_code.append('\n'+tab + ('\n'+tab).join(skeleton['code']['initial'].lineList(with_tab=True, tab_displacement=-1)))
 
+    for role in hardware_used.keys():
+        print('initializing sensors for the ' + role + '...')
+        sensor = hardware_used[role].getValue()
+        config = SAPOFTO.SAPOFTO(key=sensor + '_config', filename='sensors/' + sensor + '.org')
+        #for sensor in hardware_used[role]:
+
+        initialization_code = config['code']['initial'].lineList(with_tab=True, tab_displacement=-1)
+        session_code.append('\n' + tab + ('\n'+tab).join(initialization_code))
 
     session_code.appendLine('\n' + tab + 'try:')
     session_code.appendLine((tab * 2) + 'while(True):')
@@ -165,6 +173,9 @@ def generateSessionCode(args):
     session_code.appendLine('\n' + tab + 'except:')
     
     session_code.appendLine('\n' + tab * 2 + 'print("recording complete")')#, e)')
+    # Apply survey questions
+    #
+
     
     # ACTUAL TODO FIX THE DEBUG ^^^^^^
     # ACTUAL TODO FIX THE OUTPUT vvvvv
@@ -177,15 +188,13 @@ def generateSessionCode(args):
         initialization_code = config['code']['terminal'].lineList(with_tab=True, tab_displacement=-1)
         session_code.append(('\n'+(tab*2)) + ('\n'+(tab*2)).join(initialization_code))
 
-
-    # Apply survey questions
-    #
     for role in skeleton['SUBJECT ROLES'].keys():
         if 'SURVEY' in skeleton['SUBJECT ROLES'][role].keys():
             session_code.appendLine('\n'+tab*2+'print("Survey for ' + role + ':")')
             session_code.appendLine('\n'+tab*2+'skeleton["SUBJECT ROLES"]["'+role+'"]["SURVEY"]["TERMINAL"].applySurvey()')
 
 
+
     session_code.append('\n'+tab*2 + ('\n'+(tab*2)).join(skeleton['code']['terminal'].lineList(with_tab=True, tab_displacement=-1)))
     dotnwborglab['SESSION FOOTER'].populatePrototype(prototype_parameters)
     session_code.append('\n'+tab+dotnwborglab['SESSION FOOTER'].getValue())
